==> haskell-toml-parser-2.0.1.1-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-toml-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 toml-parser
version:              2.0.1.1
visibility:           public
id:                   toml-parser-2.0.1.1-C3auJhZyi20ARB7LvsjXY2
key:                  toml-parser-2.0.1.1-C3auJhZyi20ARB7LvsjXY2
license:              ISC
copyright:            2023 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
synopsis:             TOML 1.0.0 parser
description:
    TOML parser using generated lexers and parsers with
    careful attention to the TOML 1.0.0 semantics for
    defining tables.

category:             Text
abi:                  0c24d9b46a7efde1eb5ef73953500ccc
exposed:              True
exposed-modules:
    Toml Toml.Pretty Toml.Schema Toml.Schema.FromValue
    Toml.Schema.Generic Toml.Schema.Generic.FromValue
    Toml.Schema.Generic.ToValue Toml.Schema.Matcher
    Toml.Schema.ParseTable Toml.Schema.ToValue Toml.Semantics
    Toml.Semantics.Ordered Toml.Semantics.Types Toml.Syntax
    Toml.Syntax.Lexer Toml.Syntax.Parser Toml.Syntax.Position
    Toml.Syntax.Token Toml.Syntax.Types

hidden-modules:       Toml.Syntax.LexerUtils Toml.Syntax.ParserUtils
import-dirs:          /usr/lib/ghc-9.4.8/site-local/toml-parser-2.0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/toml-parser-2.0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/toml-parser-2.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-toml-parser
hs-libraries:         HStoml-parser-2.0.1.1-C3auJhZyi20ARB7LvsjXY2
depends:
    array-0.5.4.0 base-4.17.2.1 containers-0.6.7
    prettyprinter-1.7.1-A6lJotYEu1tDm9MBCabcNF text-2.0.2 time-1.12.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-toml-parser/html/toml-parser.haddock
haddock-html:         /usr/share/doc/haskell-toml-parser/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-toml-parser-2.0.1.1-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-toml-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 toml-parser
version:              2.0.1.1
visibility:           public
id:                   toml-parser-2.0.1.1-2qndTLP3Ca4DmQYks4d4JI
key:                  toml-parser-2.0.1.1-2qndTLP3Ca4DmQYks4d4JI
license:              ISC
copyright:            2023 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
synopsis:             TOML 1.0.0 parser
description:
    TOML parser using generated lexers and parsers with
    careful attention to the TOML 1.0.0 semantics for
    defining tables.

category:             Text
abi:                  6f730f6223c988e6d670b67598395999
exposed:              True
exposed-modules:
    Toml Toml.Pretty Toml.Schema Toml.Schema.FromValue
    Toml.Schema.Generic Toml.Schema.Generic.FromValue
    Toml.Schema.Generic.ToValue Toml.Schema.Matcher
    Toml.Schema.ParseTable Toml.Schema.ToValue Toml.Semantics
    Toml.Semantics.Ordered Toml.Semantics.Types Toml.Syntax
    Toml.Syntax.Lexer Toml.Syntax.Parser Toml.Syntax.Position
    Toml.Syntax.Token Toml.Syntax.Types

hidden-modules:       Toml.Syntax.LexerUtils Toml.Syntax.ParserUtils
import-dirs:          /usr/lib/ghc-9.4.8/site-local/toml-parser-2.0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/toml-parser-2.0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/toml-parser-2.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-toml-parser
hs-libraries:         HStoml-parser-2.0.1.1-2qndTLP3Ca4DmQYks4d4JI
depends:
    array-0.5.4.0 base-4.17.2.1 containers-0.6.7
    prettyprinter-1.7.1-3DaP0TCP9KiHFF7Mogrhb2 text-2.0.2 time-1.12.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-toml-parser/html/toml-parser.haddock
haddock-html:         /usr/share/doc/haskell-toml-parser/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
